﻿using Syncfusion.ListView.XForms;
using Syncfusion.ListView.XForms.Control.Helpers;
using System;
using System.Collections.Generic;
using System.Text;
using Xamarin.Forms;

namespace SfListViewSample
{
    public class ListViewBehavior : Behavior<SfListView>
    {
        #region Fields

        BookInfoViewModel ViewModel;
        SfListView ListView;
        VisualContainer Container;

        #endregion

        #region Override Methods

        protected override void OnAttachedTo(SfListView listView)
        {
            ListView = listView;
            listView.Loaded += ListView_Loaded;
            listView.ScrollStateChanged += ListView_ScrollStateChanged;
            Container = listView.GetVisualContainer();
            base.OnAttachedTo(listView);
        }

        protected override void OnDetachingFrom(SfListView listView)
        {
            listView.Loaded -= ListView_Loaded;
            ViewModel.PropertyChanged -= ViewModel_PropertyChanged;
            listView.ScrollStateChanged -= ListView_ScrollStateChanged;
            ViewModel = null;
            Container = null;
            ListView = null;
            base.OnDetachingFrom(listView);
        }

        #endregion

        #region Private Methods

        private void LoadHeaderItemView()
        {
            var visibleLines = Container.ScrollRows.GetVisibleLines();
            ViewModel.NeedHeaderView = visibleLines[0].LineIndex > 0;
        }

        private void LoadFooteerItemView()
        {
            var lastbodyvisiblelineindex = Container.ScrollRows.LastBodyVisibleLineIndex;
            var count = ViewModel.BookInfo.Count - lastbodyvisiblelineindex;
            ViewModel.NeedFooterView = !(lastbodyvisiblelineindex == ViewModel.BookInfo.Count - 1);
        }

        #endregion

        #region Events

        private void ListView_Loaded(object sender, ListViewLoadedEventArgs e)
        {
            ViewModel = ListView.BindingContext as BookInfoViewModel;
           
            ViewModel.PropertyChanged += ViewModel_PropertyChanged;
            ViewModel.SelectedIndex = 2;
            LoadHeaderItemView();
            LoadFooteerItemView();
        }

        private void ViewModel_PropertyChanged(object sender, System.ComponentModel.PropertyChangedEventArgs e)
        {
            if (e.PropertyName == "SelectedIndex")
            {
                ViewModel.SelectedItem = ViewModel.BookInfo[ViewModel.SelectedIndex];
                ListView.LayoutManager.ScrollToRowIndex(ViewModel.SelectedIndex, Syncfusion.ListView.XForms.ScrollToPosition.Center, false);
            }
        }

        private void ListView_ScrollStateChanged(object sender, ScrollStateChangedEventArgs e)
        {
            LoadHeaderItemView();
            LoadFooteerItemView();
        }

        #endregion
    }
}
